@@ -45,13 +45,11 @@
 
 /* desktop-wide settings */
 #define GNOME_MONOSPACE_FONT_NAME "monospace-font-name"
-#define GNOME_MENUS_HAVE_TEAROFF  "menus-have-tearoff"
 
 static LogviewPrefs *singleton = NULL;
 
 enum {
   SYSTEM_FONT_CHANGED,
-  HAVE_TEAROFF_CHANGED,
   LAST_SIGNAL
 };
 
@@ -106,30 +104,10 @@ logview_prefs_class_init (LogviewPrefsClass *klass)
                                                g_cclosure_marshal_VOID__STRING,
                                                G_TYPE_NONE, 1,
                                                G_TYPE_STRING);
-  signals[HAVE_TEAROFF_CHANGED] = g_signal_new ("have-tearoff-changed",
-                                                G_OBJECT_CLASS_TYPE (oclass),
-                                                G_SIGNAL_RUN_LAST,
-                                                G_STRUCT_OFFSET (LogviewPrefsClass, have_tearoff_changed),
-                                                NULL, NULL,
-                                                g_cclosure_marshal_VOID__BOOLEAN,
-                                                G_TYPE_NONE, 1,
-                                                G_TYPE_BOOLEAN);
 
   g_type_class_add_private (klass, sizeof (LogviewPrefsPrivate));
 }
 
-static void
-have_tearoff_changed_cb (GSettings *settings,
-                         gchar *key,
-                         gpointer data)
-{
-  LogviewPrefs *prefs = data;
-  gboolean add_tearoffs;
-
-  add_tearoffs = g_settings_get_boolean (settings, key);
-  g_signal_emit (prefs, signals[HAVE_TEAROFF_CHANGED], 0, add_tearoffs, NULL);
-}
-
 static void
 monospace_font_changed_cb (GSettings *settings,
                            gchar *key,
@@ -310,8 +288,6 @@ logview_prefs_init (LogviewPrefs *self)
 
   g_signal_connect (priv->interface_prefs, "changed::" GNOME_MONOSPACE_FONT_NAME,
                     G_CALLBACK (monospace_font_changed_cb), self);
-  g_signal_connect (priv->interface_prefs, "changed::" GNOME_MENUS_HAVE_TEAROFF,
-                    G_CALLBACK (have_tearoff_changed_cb), self);
 
   load_filters (self);
 }
@@ -365,14 +341,6 @@ logview_prefs_get_monospace_font_name (LogviewPrefs *prefs)
   return (g_settings_get_string (prefs->priv->interface_prefs, GNOME_MONOSPACE_FONT_NAME));
 }
 
-gboolean
-logview_prefs_get_have_tearoff (LogviewPrefs *prefs)
-{
-  g_assert (LOGVIEW_IS_PREFS (prefs));
-
-	return (g_settings_get_boolean (prefs->priv->interface_prefs, GNOME_MENUS_HAVE_TEAROFF));
-}
-
 /* the elements should be freed with g_free () */
 
 gchar **
